#!/bin/sh

exec_dir="/usr/bin"
doc_dir="/usr/doc/opera"
share_dir="/usr/share/opera"

# Root
  if [ `whoami` != 'root' ]
    then
      echo 'You need to be root to execute this command'
      echo 'If you do not have root priveleges you may run it by typing ./opera'
      echo 'Executing su'
      su root -c "./install.sh"
      exit
  fi

# Confirmation
  echo 'This is the install script for Opera.'
  echo 
  echo 'Files to be installed:'
  echo '--------------------'
  echo ' /usr/bin/opera'
  echo ' /usr/doc/opera/*'
  echo ' /usr/share/opera/*'
  echo ' Menu entries'
  echo '--------------------'
  echo

# License
  echo 'The Software License Agreement will now be displayed'
  echo 'Press Q to exit'
  echo 'please wait...'
  sleep 5
  less LICENSE
  echo 'Do you accept [y/n]?'

  read answer
  if [ "$answer" != "y" ] && [ "$answer" != "Y" ]
    then
      echo 'Installation aborted.'
      exit
  fi

# Executable
  chmod 755 opera
  cp -fuvp opera $exec_dir/

# Documentation
  mkdir -p $doc_dir/
  chmod 755 $doc_dir
  cp -fuvp LICENSE README $doc_dir

# Shared files
  mkdir -p $share_dir/buttons/
  chmod 755 $share_dir/buttons
  cp -Riuvp buttons/* $share_dir/buttons/

  mkdir -p $share_dir/help/
  chmod 755 $share_dir/help
  cp -Rfuvp help/* $share_dir/help/

  mkdir -p $share_dir/images/
  chmod 755 $share_dir/images
  cp -Rfuvp images/* $share_dir/images/

  mkdir -p  $share_dir/styles/
  chmod 755 $share_dir/styles
  cp -Rfuvp styles/* $share_dir/styles/

  cp -iuvp opera.adr $share_dir/

# Uninstallation
  chmod 755 uninstall.sh
  cp -fuvp uninstall.sh $share_dir/

# Icons
  if [ ! -d /usr/share/icons/ ]
    then
    mkdir -p /usr/share/icons/
  fi
  cp -fuvp opera.xpm /usr/share/icons/

  if [ ! -d /usr/share/pixmaps/ ]
    then
    mkdir -p /usr/share/pixmaps/
  fi
  cp -fuvp opera.xpm /usr/share/pixmaps/

# X11
  if [ -d /etc/X11/applnk/ ]
    then
    echo 'X11 found adding icon...'
    if [ ! -d /etc/X11/applnk/Internet ]
      then
      mkdir -p /etc/X11/applnk/Internet/
    fi
    cp -fuvp opera.desktop /etc/X11/applnk/Internet/
  fi

# Wmconfig
  if [ -d /etc/X11/wmconfig/ ] 
    then
    cp -fuvp opera.wmconfig /etc/X11/wmconfig/opera
  fi

# Kde2
  if [ -d /opt/kde2 ]
    then
      int_dir="/opt/kde2/share/applnk/Internet"
      icon_dir="/opt/kde2/share/icons"
      echo 'Kde2 found adding icon...'
      if [ -d "$icon_dir/hicolor/48x48/apps" ]
        then cp -fuvp opera_48x48.png $icon_dir/hicolor/48x48/apps/opera.png
      fi
      if [ -d "$icon_dir/hicolor/32x32/apps" ]
        then cp -fuvp opera_32x32.png $icon_dir/hicolor/32x32/apps/opera.png
      fi
      if [ -d "$icon_dir/hicolor/22x22/apps" ]
        then cp -fuvp opera_22x22.png $icon_dir/hicolor/22x22/apps/opera.png
      fi
      if [ -d "$icon_dir/locolor/32x32/apps" ]
        then cp -fuvp opera_32x32.png $icon_dir/locolor/32x32/apps/opera.png
      fi
      if [ -d "$icon_dir/locolor/22x22/apps" ]
        then cp -fuvp opera_22x22.png $icon_dir/locolor/22x22/apps/opera.png
      fi
      if [ -d "$icon_dir/locolor/16x16/apps" ]
        then cp -fuvp opera_16x16.png $icon_dir/locolor/16x16/apps/opera.png
      fi
    if [ ! -d "$int_dir" ]
      then
      mkdir -p $int_dir/
    fi
    cp -fuvp opera.desktop $int_dir/
    else
    # Non standard location
    if [ -d /usr/share/applnk/Networking/ ]
      then
      www_dir="/usr/share/applnk/Networking/WWW"
      echo 'Kde2 found adding icon...'
      if [ ! -d "$www_dir" ]
        then
        mkdir -p $www_dir/
      fi
      cp -fuvp opera.desktop $www_dir/
    fi
  fi

# Kde
  if [ -d /opt/kde ]
    then
    int_dir="/opt/kde/share/applnk/Internet"
    icon_dir="/opt/kde/share/icons"
    echo 'Kde found adding icon...'
    if [ ! -d "$icon_dir" ]
      then 
      mkdir -p $icon_dir/
    fi
    cp -fuvp opera.xpm $icon_dir/
    if [ ! -d "$int_dir" ]
      then
      mkdir -p $int_dir/
    fi
    cp -fuvp opera.desktop $int_dir/
    else
    # Non standard location
    if [ -d /usr/share/applnk ]
      then
      int_dir="/usr/share/applnk/Internet"
      echo 'Kde found adding icon...'
      if [ ! -d "$int_dir" ]
        then
        mkdir -p $int_dir/
      fi
      cp -fuvp opera.desktop $int_dir/
    fi
  fi

# Gnome
  if [ -d /opt/gnome ]
    then
    int_dir="/opt/gnome/share/gnome/apps/Internet"
    icon_dir="/opt/gnome/share/pixmaps"
    echo 'Gnome found adding icon...'
    if [ ! -d "$icon_dir" ]
      then
      mkdir -p $icon_dir/
    fi
    cp -fuvp opera.xpm $icon_dir/
    if [ ! -d "$int_dir" ]
      then
      mkdir -p $int_dir/
    fi
    cp -fuvp opera.desktop $int_dir/
    else
    # Non standard location
    if [ -d /usr/share/gnome/apps/ ]
      then
      int_dir="/usr/share/gnome/apps/Internet"
      echo 'Gnome found adding icon...'
      if [ ! -d "$int_dir" ]
        then
        mkdir -p $int_dir/
      fi
      cp -fuvp opera.desktop $int_dir/
    fi
  fi

echo 'done.'
